@@ -1,4 +1,4 @@
-from matprops import say_hello
+from src import say_hello
 
 
 def test_main_no_params():
